==> bootmachine-0.5.tar.gz: bootmachine-0.5/bootmachine/contrib/distros/rackspace_fedora_17.py <==
import os
import sys
import time

from fabric.api import cd, env, run, sudo
from fabric.context_managers import settings as fabric_settings
from fabric.contrib.files import append, put, sed, uncomment
from fabric.operations import reboot


DISTRO = "FEDORA_17"
SALT_INSTALLERS = ["rpm-stable", "rpm-epel-testing"]


def bootstrap():
    """
    Bootstrap Fedora.

    Only the bare essentials, salt takes care of the rest.

    """
    BASE_PACKAGES = [
        "curl",
        "git",
        "rsync",
    ]
    run("/usr/bin/localedef -i en_US -f UTF-8 en_US.UTF-8")
    run("export LC_ALL=en_US.UTF-8 && export LANG=en_US.UTF-8")
    append("/etc/sysconfig/i18n", 'LC_ALL="en_US.UTF-8"')
    run("yum update --assumeyes")
    run("yum groupinstall --assumeyes 'Development Tools'")
    run("yum install --assumeyes {pkgs}".format(pkgs=" ".join(BASE_PACKAGES)))

    with fabric_settings(warn_only=True):
        reboot()


def install_salt(installer="rpm"):
    """
    Install salt via rpm.
    """
    if installer == "rpm-stable":
        run("yum install --assumeyes salt-master salt-minion")
    elif installer == "rpm-testing":
        run("yum install --assumeyes --enablerepo=updates-testing salt-master salt-minion")
    else:
        raise NotImplementedError()


def start_salt():
    """
    Upload the bootmachine's bundled salt-states.
    Launch the salt-master daemon on the saltmaster server.
    Launch a salt-minion daemon on all servers, including the saltmaster.
    """
    if env.host == env.master_server.public_ip:
        run("systemctl enable salt-master.service")
        run("systemctl start salt-master.service")

    sed("/etc/salt/minion", "\#master\: salt", "master: {ip_addr}".format(
        ip_addr=env.master_server.private_ip))

    run("systemctl enable salt-minion.service")
    run("systemctl start salt-minion.service")


def restart_salt():
    """
    Restarts salt master and/or minions.
    """
    with fabric_settings(warn_only=True):
        if env.host == env.master_server.public_ip:
            sudo("systemctl restart salt-master.service")
            time.sleep(3)
            sudo("systemctl restart salt-minion.service")
        else:
            sudo("systemctl restart salt-minion.service")

==> bootmachine-0.5.1.tar.gz: bootmachine-0.5.1/bootmachine/contrib/distros/rackspace_fedora_17.py <==
import time

from fabric.api import env, run, sudo
from fabric.context_managers import settings as fabric_settings
from fabric.contrib.files import append, sed
from fabric.operations import reboot


DISTRO = "FEDORA_17"
SALT_INSTALLERS = ["rpm-stable", "rpm-epel-testing"]


def bootstrap():
    """
    Bootstrap Fedora.

    Only the bare essentials, salt takes care of the rest.

    """
    base_packages = [
        "curl",
        "git",
        "rsync",
    ]
    run("/usr/bin/localedef -i en_US -f UTF-8 en_US.UTF-8")
    run("export LC_ALL=en_US.UTF-8 && export LANG=en_US.UTF-8")
    append("/etc/sysconfig/i18n", 'LC_ALL="en_US.UTF-8"')
    run("yum update --assumeyes")
    run("yum groupinstall --assumeyes 'Development Tools'")
    run("yum install --assumeyes {pkgs}".format(pkgs=" ".join(base_packages)))
    append("/etc/hosts", "{0} saltmaster-private".format(env.master_server.private_ip))
    with fabric_settings(warn_only=True):
        reboot()


def install_salt(installer="rpm"):
    """
    Install salt with the chosen installer.
    """
    if installer == "rpm-stable":
        run("yum install --assumeyes salt-master salt-minion")
    elif installer == "rpm-testing":
        run("yum install --assumeyes --enablerepo=updates-testing salt-master salt-minion")
    else:
        raise NotImplementedError()


def setup_salt():
    """
    Setup the salt configuration files and enable dameon on a reboot.
    """
    server = [s for s in env.bootmachine_servers if s.public_ip == env.host][0]

    if env.host == env.master_server.public_ip:
        run("systemctl enable salt-master.service")
    run("systemctl enable salt-minion.service")

    sed("/etc/salt/minion", "#master: salt", "master: saltmaster-private")
    append("/etc/salt/minion", "grains:\n  roles:")
    for role in server.roles:
        append("/etc/salt/minion", "    - {0}".format(role))


def start_salt():
    """
    Starts salt master and minions.
    """
    if env.host == env.master_server.public_ip:
        sudo("systemctl restart salt-master.service")
        time.sleep(3)
        sudo("systemctl restart salt-minion.service")
    else:
        sudo("systemctl restart salt-minion.service")


def restart_salt():
    """
    Restarts salt master and minions.
    """
    with fabric_settings(warn_only=True):
        if env.host == env.master_server.public_ip:
            sudo("systemctl restart salt-master.service")
            time.sleep(3)
            sudo("systemctl restart salt-minion.service")
        else:
            sudo("systemctl restart salt-minion.service")
